==> ann-0.2.tar.gz: ann-0.2/lib/ann_ds.cpp <==
/***************************************************************************
                          ann_ds.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_ds.h>

  //               //
 // class ANN::DS //
//               //

ANN::DS::~DS()
{
  if (des_out && (des_out!=this)) delete des_out;
}

bool
ANN::DS::resize(const Loc &sizes_)
{
  return false;
}

bool
ANN::DS::resize(const Size &sizes_)
{
  return false;
}

bool
ANN::DS::resize(size_t dimension_, size_t *positions_)
{
  return false;
}

bool
ANN::DS::resize(size_t *positions_)
{
  return false;
}

bool
ANN::DS::set_len(size_t len_)
{
  DS   *in=input();
  bool  ret;
  ret=in->do_set_len(len_);
  if (des_out) des_out->do_set_len(len_);
  return ret;
}

bool
ANN::DS::do_seek(size_t term_pos_)
{
  return false;
}

bool
ANN::DS::do_set_len(size_t len_)
{
  return false;
}

const ANN::Size &
ANN::DS::get_sizes() const
{
  return term().get_sizes();
}

size_t
ANN::DS::get_size() const
{
  return term().get_size();
}

bool
ANN::DS::reset()
{
  bool ret=input()->do_reset();
  if (ret && des_out) des_out->do_reset();
  return ret;
}

void
ANN::DS::next()
{
  DS *in=input();
  in->do_next();
  if (des_out && !des_out->do_seek(in->where()))
    des_out->do_next();
}

bool
ANN::DS::seek(size_t term_pos_)
{
  DS *in=input();
  bool ret=in->do_seek(term_pos_);
  if (ret && des_out) des_out->do_seek(in->where());
  return ret;
}

ANN::Term *
ANN::DS::all_terms()
{
  return 0;
}

const ANN::Term *
ANN::DS::all_terms() const
{
  return 0;
}

ANN::DS *
ANN::DS::input()
{
  return this;
}

const ANN::DS *
ANN::DS::input() const
{
  return this;
}

  //                   //
 // class ANN::DS_des //
//                   //

ANN::DS_des::~DS_des()
{
}

size_t
ANN::DS_des::get_len() const
{
  return in->get_len();
}

size_t
ANN::DS_des::where() const
{
  return in->where();
}

ANN::DS *
ANN::DS_des::input()
{
  return in;
}

const ANN::DS *
ANN::DS_des::input() const
{
  return in;
}

==> ann-0.3.tar.gz: ann-0.3/lib/ann_ds.cpp <==
/***************************************************************************
                          ann_ds.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_ds.h>

  //               //
 // class ANN::DS //
//               //

ANN::DS::~DS()
{
  if (des_out && (des_out!=this)) delete des_out;
}

bool
ANN::DS::do_resize(const Size &sizes_)
{
  return false;
}

bool
ANN::DS::do_set_length(const Size &len_)
{
  return false;
}

bool
ANN::DS::set_length(const Size &len_)
{
  DS   *in=input();
  bool  ret;
  ret=in->do_set_length(len_);
  if (ret && des_out) des_out->do_set_length(len_);
  return ret;
}

bool
ANN::DS::do_seek(size_t term_pos_)
{
  return false;
}

bool
ANN::DS::do_locate(const Loc &loc)
{
  return false;
}

size_t
ANN::DS::get_length() const
{
  return get_lengths().total_size();
}

const ANN::Size &
ANN::DS::get_sizes() const
{
  return term().get_sizes();
}

size_t
ANN::DS::get_size() const
{
  return term().get_size();
}

bool
ANN::DS::reset()
{
  bool ret=input()->do_reset();
  if (ret && des_out) des_out->do_reset();
  return ret;
}

void
ANN::DS::next()
{
  DS *in=input();
  in->do_next();
  if (des_out && !des_out->do_locate(in->where()))
    des_out->do_next();
}

bool
ANN::DS::seek(size_t term_pos_)
{
  DS *in=input();
  bool ret=in->do_seek(term_pos_);
  if (ret && des_out) des_out->do_locate(in->where());
  return ret;
}

bool
ANN::DS::locate(const Loc &loc)
{
  DS *in=input();
  bool ret=in->do_locate(loc);
  if (ret && des_out) des_out->do_locate(in->where());
  return ret;
}

size_t
ANN::DS::which() const
{
  return get_lengths()[where()];
}

ANN::TS *
ANN::DS::all_terms()
{
  return 0;
}

const ANN::TS *
ANN::DS::all_terms() const
{
  return 0;
}

ANN::DS *
ANN::DS::input()
{
  return this;
}

const ANN::DS *
ANN::DS::input() const
{
  return this;
}

  //                   //
 // class ANN::DS_des //
//                   //

ANN::DS_des::~DS_des()
{
}

const ANN::Size &
ANN::DS_des::get_lengths() const
{
  return in->get_lengths();  
}

size_t
ANN::DS_des::get_length() const
{
  return in->get_length();
}

const ANN::Loc &
ANN::DS_des::where() const
{
  return in->where();
}

size_t
ANN::DS_des::which() const
{
  return in->which();
}

ANN::DS *
ANN::DS_des::input()
{
  return in;
}

const ANN::DS *
ANN::DS_des::input() const
{
  return in;
}
